/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'div', 'de', {
	IdInputLabel: 'Kennung',
	advisoryTitleInputLabel: 'Tooltip',
	cssClassInputLabel: 'Formatvorlagenklasse',
	edit: 'Div bearbeiten',
	inlineStyleInputLabel: 'Inline Stil',
	langDirLTRLabel: 'Links nach Rechs (LTR)',
	langDirLabel: 'Sprachrichtung',
	langDirRTLLabel: 'Rechs nach Links (RTL)',
	languageCodeInputLabel: 'Sprachcode',
	remove: 'Div entfernen',
	styleSelectLabel: 'Stil',
	title: 'Div Container erzeugen',
	toolbar: 'Div Container erzeugen'
} );
